@@ -23,7 +23,7 @@ function name(volume, muted, prefix) {
         prefix = "audio-volume";
     }
     var icon = null;
-    var percent = volume / maxVolumeValue;
+    var percent = volume / currentMaxVolumeValue;
     if (percent <= 0.0 || muted) {
         icon = prefix + "-muted";
     } else if (percent <= 0.25) {
@@ -35,3 +35,37 @@ function name(volume, muted, prefix) {
     }
     return icon;
 }
+
+function formFactorIcon(formFactor) {
+    switch(formFactor) {
+        case "internal":
+            return "audio-card";
+        case "speaker":
+            return "audio-speakers-symbolic";
+        case "phone":
+            return "phone";
+        case "handset":
+            return "phone";
+        case "tv":
+            return "video-television";
+        case "webcam":
+            return "camera-web";
+        case "microphone":
+            return "audio-input-microphone";
+        case "headset":
+            return "audio-headset";
+        case "headphone":
+            return "audio-headphones";
+        case "hands-free":
+            return "hands-free";
+        case "car":
+            return "car";
+        case "hifi":
+            return "hifi";
+        case "computer":
+            return "computer";
+        case "portable":
+            return "portable";
+    }
+    return "";
+}
